<?php

use CRM_Civi3cx_ExtensionUtil as E;

class CRM_Civi3cx_Page_Search extends CRM_Core_Page {

  public function run() {
    Civi::log()->debug('3cx search: ' . print_r($_REQUEST, 1));

    $response = [];
    $phone = CRM_Utils_Request::retrieveValue('phone', 'String');
    $email = CRM_Utils_Request::retrieveValue('email', 'String');

    // @todo Authentication

    if ($phone) {
      $response = $this->searchByPhone($phone);
    }
    elseif ($email) {
      $response = $this->searchByEmail($email);
    }
    else {
      throw new Exception('Missing phone or email');
    }

    echo json_encode($response);
    CRM_Utils_System::civiExit();
  }

  /**
   *
   */
  private function searchByPhone(String $phone) {
    $response = [];

    // Remove leading '+' if present
    $phone = preg_replace('/^\+/', '', $phone);

    // Remove leading country code if present (US/CA for now)
    $phone = preg_replace('/^1/', '', $phone);

    $dao = CRM_Core_DAO::executeQuery('SELECT * FROM civicrm_phone WHERE phone_numeric LIKE %1 ORDER BY id ASC', [
      1 => ['%' . $phone, 'String'],
    ]);

    if ($dao->fetch()) {
      $response['contact'] = $this->getContactByID($dao->contact_id);
    }
    else {
      Civi::log()->debug('3cx: searchByPhone: ' . $phone . ': not found');
    }

    return $response;
  }

  /**
   *
   */
  private function searchByEmail(String $email) {
    $response = [];

    $dao = CRM_Core_DAO::executeQuery('SELECT * FROM civicrm_email WHERE email = %1 ORDER BY id ASC', [
      1 => [$email, 'String'],
    ]);

    if ($dao->fetch()) {
      $response['contact'] = $this->getContactByID($dao->contact_id);
    }
    else {
      Civi::log()->debug('3cx: searchByEmail: ' . $email . ': not found');
    }

    return $response;
  }

  /**
   *
   */
  private function getContactByID($contact_id) {
    Civi::log()->debug('3cx: getContactByID: ' . $contact_id);

    // @todo Check the contact_type?
    $contact = civicrm_api3('Contact', 'getsingle', [
      'id' => $contact_id,
    ]);

    return [
      'id' => $contact['id'],
      'firstname' => $contact['first_name'],
      'lastname' => $contact['last_name'],
      'company' => $contact['current_employer'],
      'email' => $contact['email'],
      'url' => $contact['image_URL'],
    ];
  }

}
